```{toctree}
---
maxdepth: 3
caption: Getting Started
hidden: true
---

Installation <getting_started/installation>
```

```{toctree}
---
maxdepth: 3
caption: Tutorials
hidden: true
---
tutorials/h3
tutorials/healpix
```

<!-- ```{toctree} -->
<!-- --- -->
<!-- maxdepth: 3 -->
<!-- caption: User guide -->
<!-- hidden: true -->
<!-- --- -->
<!-- ``` -->

```{toctree}
---
maxdepth: 3
caption: Reference guide
hidden: true
---

Changelog <changelog>
API Reference <api>
Publications <reference_guide/publications>
```

# Welcome to `xdggs`

[![PyPI](https://img.shields.io/pypi/v/xdggs.svg?style=flat)](https://pypi.org/project/xdggs)

_xdggs_ provides an accessor (`DataArray.dggs` or `Dataset.dggs`) that allows you to work with data on a discrete global grid system using {doc}`xarray:index` objects.
